** 	SPSS program to create Revised unmet need variable as described in
	Analytical Study 25: Revising Unmet Need for Family Planing
	by Bradley, Croft, Fishel, and Westoff, 2012, published by ICF International
	measuredhs.com/pubs/pdf/AS25/AS25.pdf
** 	Program written by Trevor Croft and edited by Sarah Bradley, last updated 26 January 2011
	TCroft@icfi.com
**  Corrections 19 March 2013 for Cambodia 2010 - Trevor Croft.
**  Correction 25 May 2013 (updated 7 July 2013) for Tanzania 2010 - Trevor Croft.
**  Correction 12 March 2014 for the selection of currently married women in the frequencies at the end.  Now uses v502=1, not v501=1 - Trevor Croft.
** 	This program includes survey-specific code for the following surveys:
	Brazil 1996
	Cambodia 2010
	Colombia 2010
	Cote D'Ivoire 1994
	Gabon 2000
	Guatemala 1998-99
	Guatemala 1995
	Haiti 1994-95
	India 1992-93
	India 1998-99
	India 2005-06
	Jordan 2002
	Kazakhstan 1999
	Lesotho 2009
	Madagascar 1992
	Maldives 2009
	Mauritania 2000
	Morocco 2003-04
	Nepal 2006
	Niger 1992
	Tanzania 1996
	Tanzania 1999
	Tanzania 2010
	Turkey 1993
	Turkey 1998
	Turkey 2003
	Uganda 1995
	Yemen 1991.
**	Note that some statements will generate an error message if the variable mentioned does not exist in a particular survey - this should not cause a problem.
**  Correction 10 May 2017 to work with DHS7 datasets
    Two changes: checks for v000 now look for "7", and tsinceb now calculated using v222 which is based on century day codes in DHS7.
**  Correction 17 March 2021 Trevor Croft: to work with DHS8 datasets, additional survey specific code, and to conform to standard coding of v626a.

**Set unmet need to NA for unmarried women if survey only included ever-married women .
if (v502<>1 & v020=1) unmet=98.
* includes DHS II survey (v605 only asked to married women),
* Morocco 2003-04, Turkey 1998 (no sexual activity data for unmarried women),
* Cote D'Ivoire 1994, Haiti 1994-95 (v605 only asked to married women)
* India 2005-06 (v605 only asked to ever-married women), Nepal 2006 (v605 not asked to unmarried and "married, guana not performed" women).
if (v502<>1 & (substr(v000,3,1)="2" | v000="MA4" | v000="TR2" | (v000="CI3" & v007=94) | v000="HT3" | v000="IA5" | v000="NP5")) unmet=98.

** CONTRACEPTIVE USERS - GROUP 1.
do if (sysmis(unmet) & v312<>0).
* using to space - all contraceptive users, except those below.
+ compute unmet=3.
* using to limit if wants no more, sterilized, or declared infecund.
+ if (v605>=5 & v605<=7) unmet=4.
end if.

**PREGNANT or POSTPARTUM AMENORRHEIC (PPA) WOMEN - GROUP 2.
* Determine who should be in Group 2.
* generate time since last birth.
compute tsinceb=v222.

* generate time since last period in months from v215.
if (v215>=100 & v215<=190) tsincep=trunc((v215-100)/30).
if (v215>=200 & v215<=290) tsincep=trunc((v215-200)/4.3).
if (v215>=300 & v215<=390) tsincep=(v215-300).
if (v215>=400 & v215<=490) tsincep=(v215-400)*12.
* initialize pregnant or postpartum amenorrheic (PPA) women.
compute pregPPA=0.
if (v213=1 | m6$1=96) pregPPA=1.
* For women with missing data or "period not returned" on date of last menstrual period, use information from time since last period.
do if (sysmis(m6$1) | m6$1=99 | m6$1=97).
*   if last period is before last birth in last 5 years.
+ if (not sysmis(tsinceb) & not sysmis(tsincep) & tsincep>tsinceb & tsinceb<60) pregPPA=1.
*   if said "before last birth" to time since last period in the last 5 years.
+ if (not sysmis(tsinceb) & v215=995 & tsinceb<60) pregPPA=1.
end if.

* select only women who are pregnant or PPA for <24 months.
compute pregPPA24=0.
if (v213=1 | (pregPPA=1 & not sysmis(tsinceb) & tsinceb<24)) pregPPA24=1.

* Classify wantedness of current pregnancy/last birth.
* current pregnancy.
compute wantedlast=v225.
* recode 'God's will' (survey-specific response) as not in need for Niger 1992.
if (v000="NI2" & wantedlast=4) wantedlast=1.
* last birth.
if ((sysmis(wantedlast) | wantedlast=9) & v213<>1) wantedlast = m10$1.
* recode 'not sure' and 'don't know' (country-specific responses) as unmet need for spacing for Cote D'Ivoire 1994 and Madagascar 1992.
recode wantedlast (4, 8 = 2).
variable labels wantedlast "Wantedness of current pregnancy or last birth".
value labels wantedlast 1 "Then" 2 "Later" 3 "Not at all".
formats wantedlast (f1.0).

* Unmet need status of pregnant women or women PPA for <24 months.
do if (sysmis(unmet) & pregPPA24=1).
* no unmet need if wanted current pregnancy/last birth then/at that time.
+ if (wantedlast=1) unmet=7.
* unmet need for spacing if wanted current pregnancy/last birth later.
+ if (wantedlast=2) unmet=1.
* unmet need for limiting if wanted current pregnancy/last birth not at all.
+ if (wantedlast=3) unmet=2.
* missing=missing.
+ if (sysmis(wantedlast) | wantedlast=9) unmet=99.
end if.


**DETERMINE FECUNDITY - GROUP 3.
compute infec=0.
**Boxes 1-4 only apply to women who are not pregnant and not PPA<24 months.
do if (sysmis(unmet) & v213<>1 & pregPPA24<>1).
+ compute infec=0.

**Box 1 - applicable only to currently married.
* married 5+ years ago, no children in past 5 years, never used contraception, excluding pregnant and PPA <24 months.
+ do if (v502=1 & not sysmis(v512) & v512>=5 & (sysmis(tsinceb) | tsinceb>59) & pregPPA24<>1).
+   if (v302 =0 ) infec=1 .
* in DHS VI, v302 replaced by v302a.
+   if (v302a=0 & (substr(v000,3,1)="6" | substr(v000,3,1)="7" | substr(v000,3,1)="8")) infec=1 .
* the following two lines will generate error messages if the variable does not exist in the dataset you are using, but the error message can be ignored.
* survey-specific code for Cambodia 2010.
+   if (s313 =0 & v000="KH5" & (v007=2010 | v007=2011)) infec=1 .
* survey-specific code for Tanzania 2010.
+   if (s309b=0 & v000="TZ5" & (v007=2009 | v007=2010)) infec=1 .
+ end if.

**Box 2.
* declared infecund on future desires for children.
+ if (v605=7) infec=2.

**Box 3.
* menopausal/hysterectomy on reason not using contraception - slightly different recoding in DHS III and IV+.
* DHS IV+ surveys.
+ if (v3a08d=1 & (substr(v000,3,1)="4" | substr(v000,3,1)="5" | substr(v000,3,1)="6" | substr(v000,3,1)="7" | substr(v000,3,1)="8")) infec=3.
* DHSIII surveys.
+ if (v375a=23 & (substr(v000,3,1)="3" | substr(v000,3,1)="T")) infec=3.
* special code for hysterectomy for Brazil 1996, Guatemala 1995 and 1998-9  (code 23 = menopausal only).
+ if (v375a=28 & (v000="BR3" | v000="GU3")) infec=3.
* Reason not using did not exist in DHSII, use reason not intending to use in future.
+ if (v376=14 & substr(v000,3,1)="2") infec=3.

* below set of codes are all survey-specific replacements for reason not using contraception.
* the following lines will generate error messages if the variable does not exist in the dataset you are using, but the error message can be ignored.
* survey-specific code for Cote D'Ivoire 1994.
if (v000= "CI3" & v007=94 & v376=23) infec=3.
* survey-specific code for Gabon 2000.
if (v000= "GA3" & s607d=1) infec=3.
* survey-specific code for Haiti 1994/95.
if (v000= "HT3" & v376=23) infec=3.
* survey-specific code for Jordan 2002.
if (v000= "JO4" & (v376=23 | v376=24)) infec=3.
* survey-specific code for Kazakhstan 1999.
if (v000= "KK3" & v007=99 & s607d=1) infec=3.
* survey-specific code for Maldives 2009.
if (v000= "MV5" & v376=23) infec=3.
* survey-specific code for Mauritania 2000.
if (v000= "MR3" & s607c=1) infec=3.
* survey-specific code for Tanzania 1999.
if (v000= "TZ3" & v007=99 & s607d=1) infec=3.
* survey-specific code for Turkey 2003.
if (v000= "TR4" & v375a=23) infec=3.

**Box 4.
* Time since last period is >=6 months and not PPA.
+ if (not sysmis(tsincep) & tsincep>=6 & pregPPA<>1) infec=4.

**Box 5.
* menopause/hysterectomy on time since last period.
+ if (v215=994) infec=5.
* hysterectomy has different code for some surveys, but in 3 surveys it means "currently pregnant" - Yemen 1991, Turkey 1998, Uganda 1995).
+ if (v215=993 & v000 <> "TR3" & v000 <> "UG3" & v000 <> "YE2") infec=5.
* never menstruated on time since last period, unless had a birth in the last 5 years.
+ if (v215=996 & (sysmis(tsinceb) | tsinceb>59)) infec=5.

**Box 6.
* time since last birth>= 60 months and last period was before last birth.
+ if (v215=995 & not sysmis(tsinceb) & tsinceb>59) infec=6.
* never had a birth, but last period reported as before last birth - assume code should have been 994 or 996.
+ if (v215=995 & sysmis(tsinceb)) infec=6.

**INFECUND - GROUP 3.
+ if (infec>0 & sysmis(unmet)) unmet=9.

** End of code for women who are not pregnant and not PPA<24 months.
end if.

**NO NEED FOR UNMARRIED WOMEN WHO ARE NOT SEXUALLY ACTIVE.
* determine if sexually active in last 30 days.
compute sexact=0.
if (v528>=0 & v528<=30) sexact=1.
* older surveys used code 95 for sex in the last 4 weeks (Tanzania 1996).
if (v528=95) sexact=1.
variable labels sexact "Sexually active in last 30 days".
value labels sexact 1 "Yes" 2 "No".
formats sexact (f1.0).

* if unmarried and never had sex, assume no need.
if (sysmis(unmet) & v502<>1 & v525=0) unmet=0. 
* if unmarried and not sexually active in last 30 days, assume no need.
if (sysmis(unmet) & v502<>1 & sexact<>1) unmet=8. 

**FECUND WOMEN - GROUP 4.
do if sysmis(unmet).
* wants within 2 years.
+ if (v605=1) unmet=7.
* survey-specific code: treat 'up to god' (country-specific response) as not in need for India (different codes for 1992-3 and 1998-9).
+ if (v605=9 & v000="IA3") unmet=7.
+ if (v602=6 & v000="IA2") unmet=7.
* wants in 2+ years, wants undecided timing, or unsure if wants.
* survey-specific code for Lesotho 2009.
+ if (v000="LS5" & sysmis(v605)) v605=4.
+ if (v605>=2 & v605<=4) unmet=1.
* wants no more.
+ if (v605=5) unmet=2.
end if.

recode unmet (sysmis=99).

value labels unmet
  0 "never had sex"
  1 "unmet need for spacing"
  2 "unmet need for limiting"
  3 "using for spacing"
  4 "using for limiting"
  7 "no unmet need"
  8 "not sexually active"
  9 "infecund or menopausal"
 98 "unmarried - EM sample or no data"
 99 "missing"
.

recode unmet (1,2=1) (else=0) into unmettot.
variable labels unmettot "Unmet need for family planning".
value labels unmettot 1 "unmet need" 0  "no unmet need".
formats unmet unmettot (f1.0).

** Turkey 2003 -  section 6 only used if cluster even, household number even or cluster odd, household number odd.
select if (v000<>"TR4" | (mod(v001,2) = mod(v002,2))).


**TABULATE RESULTS.
* generate sampling weight.
compute wgt=v005/1000000.
weight by wgt.

**married.
use all.
compute filter_$=(v502=1).
filter by filter_$.
frequencies unmet, unmettot.

**all women.
use all.
frequencies unmet, unmettot.

**sexually active unmarried.
use all.
compute filter_$=(v502<>1 & sexact=1).
filter by filter_$.
frequencies unmet, unmettot.

